@@ -14,12 +14,16 @@ import copy
 from xicsrt.objects._ConfigObject import ConfigObject
 from xicsrt.tools import xicsrt_misc
 
+from xicsrt import _version
+
+log = logging.getLogger(__name__)
+
 try:
     import xicsrt_contrib
 except:
-    logging.debug('The xicrsrt_contrib package is not installed.')
+    log.debug('The xicrsrt_contrib package is not installed.')
 else:
-    logging.debug('The xicrsrt_contrib package is installed.')
+    log.debug('The xicrsrt_contrib package is installed.')
 
 
 def default_config():
@@ -158,9 +162,13 @@ def default_config():
       specific information. (Note: control of logging/debugging output is
       controlled through a separate option that is not yet implemented.)
 
+    version: string
+      The version number of xicsrt when this config was created.
+      This option is set internally and should not be modified by the user.
     """
     config = dict()
     config['general'] = dict()
+    config['general']['version'] = _version.__version__
     config['general']['number_of_iter'] = 1
     config['general']['number_of_runs'] = 1
     config['general']['random_seed'] = None
@@ -204,6 +212,39 @@ def get_config(config_user=None):
     return config
 
 
+def refresh_config(config_new):
+    """
+    When a config file is loaded from a another system or from a different user
+    it may contain default values that are not appropriate for the current
+    environment. This function will overwrite these options with new default
+    values where appropriate.
+    """
+
+    refresh = {}
+    refresh['general'] = {}
+    refresh['general']['pathlist_default'] = None
+
+    config_new = copy.deepcopy(config_new)
+    update_config(
+        config_new,
+        refresh,
+        strict=False,
+        update=True,
+        ignore_none=False,
+        )
+
+    config = default_config()
+    update_config(
+        config,
+        config_new,
+        strict=False,
+        update=True,
+        ignore_none=True,
+        )
+
+    return config
+
+
 def get_pathlist_default():
     """
     Return a list of the default sources and optics directories.
@@ -250,10 +291,17 @@ def config_from_numpy(obj):
     return obj
 
 
-def update_config(config, config_new, strict=None, update=None):
+def update_config(
+        config,
+        config_new,
+        strict=None,
+        update=None,
+        ignore_none=None,
+        ):
     """
     Overwrite any values in the given config dict with the values in the
-    user dict.  This will be done recursively to allow nested dictionaries.
+    config_new dict.  This will be done recursively to allow nested
+    dictionaries.
 
     keywords:
       strict (True)
@@ -264,12 +312,22 @@ def update_config(config, config_new, strict=None, update=None):
         If True any unmatched options that are found will be retained.
         When False they will simply be ignored. This option has no effect
         unless strict = False.
+
+      ignore_none (False)
+        If True any options found in config_new with a value of None will
+        be ignored.
+
     """
-    config_new = copy.deepcopy(config_new)
-    _update_config_dict(config, config_new, strict, update)
+    _update_config_dict(config, config_new, strict, update, ignore_none)
 
 
-def _update_config_dict(config, config_new, strict=None, update=None):
+def _update_config_dict(
+        config,
+        config_new,
+        strict=None,
+        update=None,
+        ignore_none=None,
+        ):
     """
     Recursive worker function for `update_config`.
     """
@@ -277,6 +335,8 @@ def _update_config_dict(config, config_new, strict=None, update=None):
         strict = True
     if update is None:
         update = False
+    if ignore_none is None:
+        ignore_none = False
 
     if config_new is None:
         return
@@ -289,6 +349,15 @@ def _update_config_dict(config, config_new, strict=None, update=None):
                 config[key] = config_new[key]
         else:
             if isinstance(config[key], dict):
-                _update_config_dict(config[key], config_new[key], strict=strict, update=update)
+                _update_config_dict(
+                    config[key],
+                    config_new[key],
+                    strict=strict,
+                    update=update,
+                    ignore_none=ignore_none
+                    )
             else:
-                config[key] = config_new[key]
+                if ignore_none and config_new[key] is None:
+                    pass
+                else:
+                    config[key] = config_new[key]
